"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _react = require("react");

var _react2 = require("@emotion/react");

/** @jsx jsx */
var flexAlignItemsMap = {
  center: (0, _react2.css)({
    alignItems: 'center'
  }),
  baseline: (0, _react2.css)({
    alignItems: 'baseline'
  }),
  flexStart: (0, _react2.css)({
    alignItems: 'flex-start'
  }),
  flexEnd: (0, _react2.css)({
    alignItems: 'flex-end'
  }),
  start: (0, _react2.css)({
    alignItems: 'start'
  }),
  end: (0, _react2.css)({
    alignItems: 'end'
  })
};
var flexJustifyContentMap = {
  center: (0, _react2.css)({
    justifyContent: 'center'
  }),
  flexStart: (0, _react2.css)({
    justifyContent: 'flex-start'
  }),
  flexEnd: (0, _react2.css)({
    justifyContent: 'flex-end'
  }),
  start: (0, _react2.css)({
    justifyContent: 'start'
  }),
  end: (0, _react2.css)({
    justifyContent: 'end'
  })
};
var flexWrapMap = {
  wrap: (0, _react2.css)({
    flexWrap: 'wrap'
  })
};
var baseStyles = (0, _react2.css)({
  display: 'flex',
  boxSizing: 'border-box',
  flexDirection: 'row'
});
var dividerStyles = (0, _react2.css)({
  margin: '0 -2px',
  color: "var(--ds-text-subtle, #42526E)",
  pointerEvents: 'none',
  userSelect: 'none'
});

var Divider = function Divider(_ref) {
  var children = _ref.children;
  return (0, _react2.jsx)("span", {
    css: dividerStyles
  }, children);
};
/**
 * __Inline__
 *
 * Inline is a primitive component based on flexbox that manages the horizontal layout of direct children.
 * Renders a `div` by default.
 *
 * @example
 * ```tsx
 * const App = () => (
 *   <Inline gap="space.100">
 *     <Button />
 *     <Button />
 *   </Inline>
 * )
 * ```
 */


var Inline = /*#__PURE__*/(0, _react.memo)( /*#__PURE__*/(0, _react.forwardRef)(function (_ref2, ref) {
  var gap = _ref2.gap,
      alignItems = _ref2.alignItems,
      justifyContent = _ref2.justifyContent,
      flexWrap = _ref2.flexWrap,
      divider = _ref2.divider,
      UNSAFE_style = _ref2.UNSAFE_style,
      rawChildren = _ref2.children,
      testId = _ref2.testId;
  var dividerComponent = typeof divider === 'string' ? (0, _react2.jsx)(Divider, null, divider) : divider;
  var children = divider ? _react.Children.toArray(rawChildren).filter(Boolean).map(function (child, index) {
    return (0, _react2.jsx)(_react.Fragment, {
      key: index
    }, divider && index > 0 ? dividerComponent : null, child);
  }) : rawChildren;
  return (0, _react2.jsx)("div", {
    style: UNSAFE_style,
    css: [baseStyles, gap && columnGapMap[gap], alignItems && flexAlignItemsMap[alignItems], justifyContent && flexJustifyContentMap[justifyContent], flexWrap && flexWrapMap[flexWrap]],
    "data-testid": testId,
    ref: ref
  }, children);
}));
Inline.displayName = 'Inline';
var _default = Inline;
/**
 * THIS SECTION WAS CREATED VIA CODEGEN DO NOT MODIFY {@see http://go/af-codegen}
 * @codegen <<SignedSource::3bb74c0e18d35310a98408ecd49c1526>>
 * @codegenId spacing
 * @codegenCommand yarn codegen-styles
 * @codegenParams ["columnGap"]
 * @codegenDependency ../../../tokens/src/artifacts/tokens-raw/atlassian-spacing.tsx <<SignedSource::a2b43f8447798dfdd9c6223bd22b78c7>>
 */

exports.default = _default;
var columnGapMap = {
  'scale.0': (0, _react2.css)({
    columnGap: "var(--ds-space-0, 0px)"
  }),
  'scale.025': (0, _react2.css)({
    columnGap: "var(--ds-space-025, 2px)"
  }),
  'scale.050': (0, _react2.css)({
    columnGap: "var(--ds-space-050, 4px)"
  }),
  'scale.075': (0, _react2.css)({
    columnGap: "var(--ds-space-075, 6px)"
  }),
  'scale.100': (0, _react2.css)({
    columnGap: "var(--ds-space-100, 8px)"
  }),
  'scale.1000': (0, _react2.css)({
    columnGap: "var(--ds-space-1000, 80px)"
  }),
  'scale.150': (0, _react2.css)({
    columnGap: "var(--ds-space-150, 12px)"
  }),
  'scale.200': (0, _react2.css)({
    columnGap: "var(--ds-space-200, 16px)"
  }),
  'scale.250': (0, _react2.css)({
    columnGap: "var(--ds-space-250, 20px)"
  }),
  'scale.300': (0, _react2.css)({
    columnGap: "var(--ds-space-300, 24px)"
  }),
  'scale.400': (0, _react2.css)({
    columnGap: "var(--ds-space-400, 32px)"
  }),
  'scale.500': (0, _react2.css)({
    columnGap: "var(--ds-space-500, 40px)"
  }),
  'scale.600': (0, _react2.css)({
    columnGap: "var(--ds-space-600, 48px)"
  }),
  'scale.800': (0, _react2.css)({
    columnGap: "var(--ds-space-800, 64px)"
  })
};
/**
 * @codegenEnd
 */