/** @jsx jsx */
import { forwardRef, memo } from 'react';
import { css, jsx } from '@emotion/react';
const flexAlignItemsMap = {
  center: css({
    alignItems: 'center'
  }),
  baseline: css({
    alignItems: 'baseline'
  }),
  flexStart: css({
    alignItems: 'flex-start'
  }),
  flexEnd: css({
    alignItems: 'flex-end'
  }),
  start: css({
    alignItems: 'start'
  }),
  end: css({
    alignItems: 'end'
  })
};
const flexJustifyContentMap = {
  center: css({
    justifyContent: 'center'
  }),
  flexStart: css({
    justifyContent: 'flex-start'
  }),
  flexEnd: css({
    justifyContent: 'flex-end'
  }),
  start: css({
    justifyContent: 'start'
  }),
  end: css({
    justifyContent: 'end'
  })
};
const flexWrapMap = {
  wrap: css({
    flexWrap: 'wrap'
  })
};
const baseStyles = css({
  display: 'flex',
  boxSizing: 'border-box',
  flexDirection: 'column'
});
/**
 * __Stack__
 *
 * Stack is a primitive component based on flexbox that manages the vertical layout of direct children.
 * Renders a `div` by default.
 *
 */

const Stack = /*#__PURE__*/memo( /*#__PURE__*/forwardRef(({
  gap,
  alignItems,
  justifyContent,
  flexWrap,
  children,
  UNSAFE_style,
  testId
}, ref) => {
  return jsx("div", {
    style: UNSAFE_style,
    css: [baseStyles, gap && rowGapMap[gap], alignItems && flexAlignItemsMap[alignItems], justifyContent && flexJustifyContentMap[justifyContent], flexWrap && flexWrapMap[flexWrap]],
    "data-testid": testId,
    ref: ref
  }, children);
}));
Stack.displayName = 'Stack';
export default Stack;
/**
 * THIS SECTION WAS CREATED VIA CODEGEN DO NOT MODIFY {@see http://go/af-codegen}
 * @codegen <<SignedSource::e574cf3d5b059f96c6158508fae4a064>>
 * @codegenId spacing
 * @codegenCommand yarn codegen-styles
 * @codegenParams ["rowGap"]
 * @codegenDependency ../../../tokens/src/artifacts/tokens-raw/atlassian-spacing.tsx <<SignedSource::a2b43f8447798dfdd9c6223bd22b78c7>>
 */

const rowGapMap = {
  'scale.0': css({
    rowGap: "var(--ds-space-0, 0px)"
  }),
  'scale.025': css({
    rowGap: "var(--ds-space-025, 2px)"
  }),
  'scale.050': css({
    rowGap: "var(--ds-space-050, 4px)"
  }),
  'scale.075': css({
    rowGap: "var(--ds-space-075, 6px)"
  }),
  'scale.100': css({
    rowGap: "var(--ds-space-100, 8px)"
  }),
  'scale.1000': css({
    rowGap: "var(--ds-space-1000, 80px)"
  }),
  'scale.150': css({
    rowGap: "var(--ds-space-150, 12px)"
  }),
  'scale.200': css({
    rowGap: "var(--ds-space-200, 16px)"
  }),
  'scale.250': css({
    rowGap: "var(--ds-space-250, 20px)"
  }),
  'scale.300': css({
    rowGap: "var(--ds-space-300, 24px)"
  }),
  'scale.400': css({
    rowGap: "var(--ds-space-400, 32px)"
  }),
  'scale.500': css({
    rowGap: "var(--ds-space-500, 40px)"
  }),
  'scale.600': css({
    rowGap: "var(--ds-space-600, 48px)"
  }),
  'scale.800': css({
    rowGap: "var(--ds-space-800, 64px)"
  })
};
/**
 * @codegenEnd
 */