import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
var _excluded = ["children"];

/** @jsx jsx */
import { createContext, Fragment, useContext } from 'react';
import { css, jsx } from '@emotion/react';
import invariant from 'tiny-invariant';
import surfaceColorMap from '../internal/color-map';
import { useSurface } from './surface-provider';
var asAllowlist = ['span', 'div', 'p'];
var fontFamily = "-apple-system, BlinkMacSystemFont, 'Segoe UI', 'Roboto', 'Oxygen', 'Ubuntu', 'Fira Sans', 'Droid Sans', 'Helvetica Neue', sans-serif";
var fontSizeMap = {
  '11px': css({
    fontSize: '11px'
  }),
  '12px': css({
    fontSize: '12px'
  }),
  '14px': css({
    fontSize: '14px'
  })
};
// NOTE: can't use numbers as keys or Constellation won't build. Weird one.
var fontWeightMap = {
  '400': css({
    fontWeight: 400
  }),
  '500': css({
    fontWeight: 500
  }),
  '600': css({
    fontWeight: 600
  }),
  '700': css({
    fontWeight: 700
  })
};
var lineHeightMap = {
  '12px': css({
    lineHeight: '12px'
  }),
  '16px': css({
    lineHeight: '16px'
  }),
  '20px': css({
    lineHeight: '20px'
  }),
  '24px': css({
    lineHeight: '24px'
  }),
  '28px': css({
    lineHeight: '28px'
  }),
  '32px': css({
    lineHeight: '32px'
  }),
  '40px': css({
    lineHeight: '40px'
  })
};
var textAlignMap = {
  center: css({
    textAlign: 'center'
  }),
  end: css({
    textAlign: 'end'
  }),
  start: css({
    textAlign: 'start'
  })
};
var textTransformMap = {
  none: css({
    textTransform: 'none'
  }),
  lowercase: css({
    textTransform: 'lowercase'
  }),
  uppercase: css({
    textTransform: 'uppercase'
  })
};
var verticalAlignMap = {
  top: css({
    verticalAlign: 'top'
  }),
  middle: css({
    verticalAlign: 'middle'
  }),
  bottom: css({
    verticalAlign: 'bottom'
  })
};
var baseStyles = css({
  boxSizing: 'border-box',
  margin: '0px',
  padding: '0px',
  fontFamily: fontFamily
});
var truncateStyles = css({
  overflow: 'hidden',
  textOverflow: 'ellipsis',
  whiteSpace: 'nowrap'
});
/**
 * Custom hook designed to abstract the parsing of the color props and make it clearer in the future how color is reconciled between themes and tokens.
 */

var useColor = function useColor(colorProp) {
  var surface = useSurface();
  var inverseTextColor = surfaceColorMap[surface];
  /**
   * Where the color of the surface is inverted we override the user choice
   * as there is no valid choice that is not covered by the override.
   */

  var color = inverseTextColor !== null && inverseTextColor !== void 0 ? inverseTextColor : colorProp;
  return color;
};

var HasTextAncestorContext = /*#__PURE__*/createContext(false);

var useHasTextAncestor = function useHasTextAncestor() {
  return useContext(HasTextAncestorContext);
};
/**
 * __Text__
 *
 * Text is a primitive component that has the Atlassian Design System's design guidelines baked in.
 * This includes considerations for text attributes such as color, font size, font weight, and line height.
 * It renders a `span` by default.
 *
 * @internal
 */


var Text = function Text(_ref) {
  var children = _ref.children,
      props = _objectWithoutProperties(_ref, _excluded);

  var _props$as = props.as,
      Component = _props$as === void 0 ? 'span' : _props$as,
      colorProp = props.color,
      fontSize = props.fontSize,
      fontWeight = props.fontWeight,
      lineHeight = props.lineHeight,
      _props$shouldTruncate = props.shouldTruncate,
      shouldTruncate = _props$shouldTruncate === void 0 ? false : _props$shouldTruncate,
      textAlign = props.textAlign,
      textTransform = props.textTransform,
      verticalAlign = props.verticalAlign,
      testId = props.testId,
      UNSAFE_style = props.UNSAFE_style,
      id = props.id;
  invariant(asAllowlist.includes(Component), "@atlaskit/ds-explorations: Text received an invalid \"as\" value of \"".concat(Component, "\""));
  var color = useColor(colorProp);
  var isWrapped = useHasTextAncestor();
  /**
   * If the text is already wrapped and applies no props we can just
   * render the children directly as a fragment.
   */

  if (isWrapped && Object.keys(props).length === 0) {
    return jsx(Fragment, null, children);
  }

  var component = jsx(Component, {
    style: UNSAFE_style,
    css: [baseStyles, color && textColorMap[color], fontSize && fontSizeMap[fontSize], fontWeight && fontWeightMap[fontWeight], lineHeight && lineHeightMap[lineHeight], shouldTruncate && truncateStyles, textAlign && textAlignMap[textAlign], textTransform && textTransformMap[textTransform], verticalAlign && verticalAlignMap[verticalAlign]],
    "data-testid": testId,
    id: id
  }, children);
  return isWrapped ? // no need to re-apply context if the text is already wrapped
  component : jsx(HasTextAncestorContext.Provider, {
    value: true
  }, component);
};

export default Text;
/**
 * THIS SECTION WAS CREATED VIA CODEGEN DO NOT MODIFY {@see http://go/af-codegen}
 * @codegen <<SignedSource::3d4d694e49f72e72f83ec28c1feafb76>>
 * @codegenId colors
 * @codegenCommand yarn codegen-styles
 * @codegenParams ["text"]
 * @codegenDependency ../../../tokens/src/artifacts/tokens-raw/atlassian-light.tsx <<SignedSource::07ef29d58a2b23af8b098515466d7e22>>
 */

var textColorMap = {
  'color.text': css({
    color: "var(--ds-text, #172B4D)"
  }),
  subtle: css({
    color: "var(--ds-text-subtle, #42526E)"
  }),
  subtlest: css({
    color: "var(--ds-text-subtlest, #7A869A)"
  }),
  disabled: css({
    color: "var(--ds-text-disabled, #A5ADBA)"
  }),
  inverse: css({
    color: "var(--ds-text-inverse, #FFFFFF)"
  }),
  brand: css({
    color: "var(--ds-text-brand, #0065FF)"
  }),
  selected: css({
    color: "var(--ds-text-selected, #0052CC)"
  }),
  danger: css({
    color: "var(--ds-text-danger, #DE350B)"
  }),
  warning: css({
    color: "var(--ds-text-warning, #974F0C)"
  }),
  'warning.inverse': css({
    color: "var(--ds-text-warning-inverse, #172B4D)"
  }),
  success: css({
    color: "var(--ds-text-success, #006644)"
  }),
  discovery: css({
    color: "var(--ds-text-discovery, #403294)"
  }),
  information: css({
    color: "var(--ds-text-information, #0052CC)"
  })
};
/**
 * @codegenEnd
 */